<p>
    in {{location}} <br>
    {{address}} <br>
    starting: {{starting}}
</p>
<div class="accordion-inner">
    <h4>
        description
    </h4>
    <p>
        {{description}}
    </p>
</div>
<a id="indico-link" href="{{link}}">Indico</a>